(authenticate-client username password)Like api/authenticate-client. Return an augmented api/ApiClient
that can be passed to other functions of this or the api
namespace.
Like `api/authenticate-client`. Return an augmented `api/ApiClient` that can be passed to other functions of this or the `api` namespace.
(cancel-zone-override client zone-path-or-id)Cancel a previous set-zone-temperature. This will effectively
resume the normal schedule. Unlike api/cancel-zone-temperature
this function accepts a pathname such as ["Home" "Bedroom"] as
well as a zone ID.
Cancel a previous `set-zone-temperature`. This will effectively resume the normal schedule. Unlike `api/cancel-zone-temperature` this function accepts a pathname such as ["Home" "Bedroom"] as well as a zone ID.
(get-installation client)Much like api/get-installation, but it may return a cached version of the installation, reducing the frequency of network queries for mostly-static data.
Much like api/get-installation, but it may return a cached version of the installation, reducing the frequency of network queries for mostly-static data.
(get-location client name-or-id)Much like api/get-location, but it may return a cached version of the installation, reducing the frequency of network queries for mostly-static data.
Much like api/get-location, but it may return a cached version of the installation, reducing the frequency of network queries for mostly-static data.
(get-location-status client location-name-or-id & args)Get the status of the specified location. Unlike
api/get-location-status this function accepts a user-defined name
such as "Home" as well as a location ID.
Get the status of the specified location. Unlike `api/get-location-status` this function accepts a user-defined name such as "Home" as well as a location ID.
(get-location-systems-status client location-name-or-id)Query all the temperature control systems at location. Return a
sequence of maps. See also api/get-system-status.
Query all the temperature control systems at location. Return a sequence of maps. See also `api/get-system-status`.
(get-zone-schedule client zone-path-or-id)Return the daily schedule of zone with ID zone-id. Unlike
api/get-zone-schedule this function accepts a pathname such
as ["Home" "Bedroom"] as well as a zone ID.
Return the daily schedule of zone with ID `zone-id`. Unlike `api/get-zone-schedule` this function accepts a pathname such as ["Home" "Bedroom"] as well as a zone ID.
(set-location-mode c location-name-or-id mode)Change the mode of all the temperature control systems at location.
For simple installations a location has just one TCS, thus the
location ID is enough to identify the TCS within. Unlike
api/set-system-mode this function accepts a user-defined name such
as "Home" as well as a location ID.
Change the mode of all the temperature control systems at location. For simple installations a location has just one TCS, thus the location ID is enough to identify the TCS within. Unlike `api/set-system-mode` this function accepts a user-defined name such as "Home" as well as a location ID.
(set-zone-schedule client zone-path-or-id schedule)Set the specified zone-id to have the daily plan schedule. See
get-zone-schedule. Unlike api/set-zone-schedule this function
accepts a pathname such as ["Home" "Bedroom"] as well as a zone
ID.
Set the specified `zone-id` to have the daily plan `schedule`. See `get-zone-schedule`. Unlike `api/set-zone-schedule` this function accepts a pathname such as ["Home" "Bedroom"] as well as a zone ID.
(set-zone-temperature client zone-path-or-id temperature & args)Set the specific zone's temperature. Unlike
api/set-zone-temperature this function accepts a pathname such
as ["Home" "Bedroom"] as well as a zone ID.
Set the specific zone's temperature. Unlike `api/set-zone-temperature` this function accepts a pathname such as ["Home" "Bedroom"] as well as a zone ID.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |